@@ -581,7 +581,7 @@ sub editcomment ($$) {
 			IkiWiki::saveindex();
 
 			IkiWiki::printheader($session, 202); # HTTP 202: Accepted, but not processed
-			print IkiWiki::cgitemplate($cgi, gettext(gettext("comment stored for moderation")),
+			print IkiWiki::cgitemplate($cgi, gettext("comment stored for moderation"),
 				"<p>".
 				gettext("Your comment will be posted after moderator review").
 				"</p>");
