@@ -351,7 +351,7 @@ sub merge_past ($$$) {
 		run_or_die_in($config{srcdir}, 'git', 'checkout', $config{gitmaster_branch});
 
 		# Attempt to merge without complaining.
-		if (!run_or_non_in($config{srcdir}, 'git', 'pull', '--no-commit', '.', $branch)) {
+		if (!run_or_non_in($config{srcdir}, 'git', 'pull', '--no-rebase', '--no-commit', '.', $branch)) {
 			$conflict = readfile($target);
 			run_or_die_in($config{srcdir}, 'git', 'reset', '--hard');
 		}
@@ -520,17 +520,21 @@ sub git_commit_info ($$;$) {
 
 	my @opts;
 	push @opts, "--max-count=$num" if defined $num;
-
-	my @raw_lines = run_or_die_in($dir, 'git', 'log', @opts,
-		'--pretty=raw', '--raw', '--abbrev=40', '--always', '-c',
-		'-r', $sha1, '--no-renames', '--', '.');
-
+	my @raw_lines;
 	my @ci;
-	while (my $parsed = parse_diff_tree($dir, \@raw_lines)) {
-		push @ci, $parsed;
-	}
+        
+	# Test to see if branch actually exists yet.
+	if (run_or_non_in($dir, 'git', 'show-ref', '--quiet', '--verify', '--', 'refs/heads/' . $config{gitmaster_branch}) ) {
+		@raw_lines = run_or_die_in($dir, 'git', 'log', @opts,
+			'--pretty=raw', '--raw', '--abbrev=40', '--always', '-c',
+			'-r', $sha1, '--no-renames', '--', '.');
 
-	warn "Cannot parse commit info for '$sha1' commit" if !@ci;
+		while (my $parsed = parse_diff_tree($dir, \@raw_lines)) {
+			push @ci, $parsed;
+		}
+
+		warn "Cannot parse commit info for '$sha1' commit" if !@ci;
+	};
 
 	return wantarray ? @ci : $ci[0];
 }
@@ -601,7 +605,10 @@ sub rcs_update () {
 	ensure_committer($config{srcdir});
 
 	if (length $config{gitorigin_branch}) {
-		run_or_cry_in($config{srcdir}, 'git', 'pull', '--prune', $config{gitorigin_branch});
+		run_or_cry_in($config{srcdir}, 'git', 'fetch', '--prune', $config{gitorigin_branch});
+		if (run_or_non_in($config{srcdir}, 'git', 'show-ref', '--quiet', '--verify', '--', 'refs/remotes/' . $config{gitorigin_branch} . '/' . $config{gitmaster_branch}) ) {
+			run_or_cry_in($config{srcdir}, 'git', 'merge', '--ff-only', $config{gitorigin_branch} . '/' . $config{gitmaster_branch});
+		}
 	}
 }
 
