@@ -125,7 +125,14 @@ sub preprocess (@) {
 	}
 	else {
 		# allow ImageMagick to auto-detect (potentially dangerous)
-		$format = '';
+		my $im = Image::Magick->new();
+		my $r = $im->Ping(file => $in);
+		if ($r) {
+			$format = lc $r;
+		}
+		else {
+			error sprintf(gettext("failed to determine format of %s"), $file);
+		}
 	}
 
 	error sprintf(gettext("%s image processing disabled in img_allowed_formats configuration"), $format ? $format : "\"$extension\"") unless allowed($format ? $format : "everything");
@@ -174,6 +181,15 @@ sub preprocess (@) {
 		my $r = $im->Read("$format:$srcfile\[$pagenumber]");
 		error sprintf(gettext("failed to read %s: %s"), $file, $r) if $r;
 
+		if ($config{deterministic}) {
+			$im->Set('date:create' => 0);
+			$im->Set('date:modify' => 0);
+			# Stopped working by ImageMagick 8:7.1.2.1+dfsg1-1
+			$im->Set('option'      => 'png:exclude-chunk=time');
+			# required from 8:7.1.2.1+dfsg1-1 onwards
+			$im->Set('date:timestamp' => 0);
+		}
+
 		if (! defined $im->Get("width") || ! defined $im->Get("height")) {
 			error sprintf(gettext("failed to get dimensions of %s"), $file);
 		}
