@@ -159,6 +159,18 @@ sub htmlize (@) {
 				}
 			}
 		}
+		if (! defined $markdown_sub) {
+			eval q{use CommonMark};
+			if (! $@) {
+				debug("mdwn: using CommonMark");
+				$markdown_sub=sub {
+					return CommonMark->parse(string => shift)->render(
+						format => 'html',
+						unsafe => 1,
+					);
+				}
+			}
+		}
 		if (! defined $markdown_sub) {
 			eval q{use Text::Markdown};
 			if (! $@) {
