@@ -904,7 +904,7 @@ sub refreshpot ($) {
 
 	my $doc=Locale::Po4a::Chooser::new(po4a_type($masterfile),
 					   po4a_options($masterfile));
-	$doc->read($masterfile,"?");
+	$doc->read($masterfile, "?", 'UTF-8');
 	$doc->{TT}{utf_mode} = 1;
 
 	# po4a ≥ 0.70 removed several methods
